@@ -91,7 +91,7 @@ class Epoch:
             tags=tags
         ))
 
-    def log(self, modelFilePath: Optional[str] = None, tags: Optional[list[str]] = None) -> None:
+    def log(self, modelFilePath: Optional[str] = None, tags: Optional[List[str]] = None) -> None:
         """
         Logs the epoch with optional model file and tags.
 
